
/**
 * Copyright (C) 2005-2006 Tino Reichardt
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License Version 2, as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * debug section: 8
 */

#include <stdarg.h>

/* libowfat */
#include "stralloc.h"

/* squidwall */
#include "read_controls.h"
#include "strallocX.h"
#include "log.h"

/**
 * debugging with some formatting ;)
 */
void debug_r(request_t *r, int section, int level, const char *fmt, ...)
{
	stralloc buf; /* the filled buffer */
	va_list ap;

	/* for formatting */
	stralloc *sa;
	char *s;
	int d;
	unsigned int u, x;

	section=0; level=0; /* XXX */

	stralloc_init(&buf);

	#include <stdio.h>
	printf("@debug_r() r=%p (time:%d)\n", r, (int)time(0)); fflush(stdout);

	va_start(ap, fmt);
	while (*fmt) {
		if (*fmt != '%') {
			if (!stralloc_catb(&buf, fmt++, 1)) die_nomem();
			continue;
		}

		switch (*++fmt) {
		case 's': /* string */
			s = va_arg(ap, char *);
			if (!stralloc_cats(&buf, s)) die_nomem();
			break;
		case 'd': /* int */
			d = va_arg(ap, int);
			if (!stralloc_cat_int(&buf, d)) die_nomem();
			break;
		case 'u': /* unsigned int */
			u = va_arg(ap, unsigned int);
			if (!stralloc_cat_uint(&buf, u)) die_nomem();
			break;
		case 'x': /* int (hex) - add %8x ? */
			x = va_arg(ap, unsigned int);
			if (!stralloc_cat_x32pw(&buf, x, '0', 8)) die_nomem();
			break;
		case 'S': /* stralloc */
			sa = va_arg(ap, stralloc *);
			if (!stralloc_cat(&buf, sa)) die_nomem();
			break;
		}
		fmt++;
	}
	va_end(ap);

	if (!stralloc_cats(&buf, "\n")) die_nomem();
	if (!stralloc_0(&buf)) die_nomem();

	log_timestamp(r);
	log_s(r, buf.s);
	log_flush(r);

	stralloc_free(&buf);

	return;
}
