#ifndef LOG_H
#define LOG_H

/**
 * Copyright (C) 2005-2006 Tino Reichardt
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License Version 2, as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

/* system */
#include <unistd.h>

/* squidwall */
#include "request.h"

extern void log_init(request_t *r);
extern void log_timestamp(request_t *r);
extern void log_s(request_t *r, char *s);
extern void log_sa(request_t *r, stralloc *sa);
extern void log_flush(request_t *r);
extern void log_ulong(request_t *r, unsigned long n);
extern void log_pid(request_t *r);
extern void log_tid(request_t *r);
extern void log_headline(request_t *r, char *headline);
extern int log_write(int fd, char *s, unsigned int len);

extern void debug_r(request_t *r, int section, int level, const char *fmt, ...);

#if 0
#define debug(s,l,fmt,args...)  do { debug_r(r,s,l,fmt,##args); } while (0)
#else
#define debug(s,l,fmt,args...)  do { debug_r(r,s,l,"%s() " fmt ,__func__,##args); } while (0)
#endif

#define panic(s) debug(1,1,s)

/* these should never happen! */
#define die_nomem() _exit(111)
#define die_pthread() _exit(111)

#endif
